@@ -4,7 +4,7 @@
 # Stat        <- get("Stat",        envir = asNamespace("ggplot2"))
 is.constant <- get("is.constant", envir = asNamespace("ggplot2"))
 rename_aes  <- get("rename_aes",  envir = asNamespace("ggplot2"))
-# .all_aesthetics <- get(".all_aesthetics", envir = asNamespace("ggplot2"))
+.all_aesthetics <- get(".all_aesthetics", envir = asNamespace("ggplot2"))
 
 list_to_dataframe <- get("list_to_dataframe", envir = asNamespace("plyr"))
 
